==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/Save/ts/Save_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+77"/>
        <source>Overwrite File?</source>
        <translation>Bestand overschrijven?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Het bestand &apos;%1&apos; bestaat al. Wilt u het overschrijven?</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>File Format Version Not Recommended</source>
        <translation>Bestandsformaat versie niet aanbevolen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>Het bestandsformaat versie die u gebruikt wordt niet aangeraden: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Alle zwarte objecten en lagen wordt opgeslagen als wit.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Alle gebruiker gedefinieerde kleuren worden &apos;gerond&apos; op de dichtstbijzijnde beschikbare kleur.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Proceed?</source>
        <translation>Voortgaan?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saving...</source>
        <translation>Opslaan...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Opslaan naar bestandsformaat versie &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Zwarte objecten en lagen wordt opgeslagen als wit.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Gebruiker gedefinieerde kleuren worden &apos;gerond&apos; op de dichtstbijzijnde beschikbare kleur.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Bestand %1 kon niet worden opgeslagen.</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saved drawing:</source>
        <translation>Opgeslagen tekening:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>O&amp;pslaan</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/Save/ts/Save_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>Overwrite File?</source>
        <translation>Bestand overschrijven?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Het bestand &apos;%1&apos; bestaat al. Wilt u het overschrijven?</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>File Format Version Not Recommended</source>
        <translation>Bestandsformaat versie niet aanbevolen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>Het bestandsformaat versie die u gebruikt wordt niet aangeraden: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom properties will not be saved.</source>
        <translation>Gebruiker gedefinieerde eigenschappen worden niet opgeslagen.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Alle zwarte objecten en lagen wordt opgeslagen als wit.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Alle gebruiker gedefinieerde kleuren worden &apos;gerond&apos; op de dichtstbijzijnde beschikbare kleur.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Proceed?</source>
        <translation>Voortgaan?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saving...</source>
        <translation>Opslaan...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Opslaan naar bestandsformaat versie &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Zwarte objecten en lagen wordt opgeslagen als wit.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Gebruiker gedefinieerde kleuren worden &apos;gerond&apos; op de dichtstbijzijnde beschikbare kleur.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Bestand %1 kon niet worden opgeslagen.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Saved drawing:</source>
        <translation>Opgeslagen tekening:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>O&amp;pslaan</translation>
    </message>
</context>
</TS>
